#include <sta/rtos/timer.hpp>
#include <sta/debug/debug.hpp>
#include <sta/debug/assert.hpp>

namespace sta {
	RtosTimer::RtosTimer(){}

    RtosTimer::RtosTimer(void (*callback)(void *arg), void *arg) {
        timer_id_ = osTimerNew(callback, osTimerOnce, arg, NULL);
        STA_ASSERT_MSG(timer_id_ != NULL, "Failed to initialize timer");
    }

    RtosTimer::~RtosTimer() {
        osTimerDelete(timer_id_);
    }

    void RtosTimer::start(uint32_t millis) {
        osStatus_t status = osTimerStart(timer_id_, millis);

        if (status != osOK) STA_DEBUG_PRINTLN("Timer start failed");
    }

    void RtosTimer::stop() {
        osStatus_t status = osTimerStop(timer_id_);
        
        if (status != osOK) STA_DEBUG_PRINTLN("Timer stop failed");
    }

    bool RtosTimer::isRunning() {
        return osTimerIsRunning(timer_id_);
    }
} // namespace sta
